@@ -10,15 +10,15 @@ use JSON qw(encode_json decode_json);
 sub build {
     my ($self, %args) = @_;
 
-    $self->app->{default_content_type} = $args{content_type} || 'application/json';
     $self->register(
-        'deserialize' => sub { deserialize($_[1]) },
-        'serialize'   => sub { serialize($_[1]) },
+        serializer => $self,
     );
 }
 
-sub deserialize { decode_json shift }
-sub serialize   { encode_json shift }
+sub content_type { 'application/json' }
+
+sub deserialize { decode_json $_[1] }
+sub serialize   { encode_json $_[1] }
 
 1;
 
@@ -30,6 +30,6 @@ Raisin::Plugin::Format::JSON - JSON serialization plugin for Raisin.
 
 =head1 DESCRIPTION
 
-Provides C<deserialize> and C<serialize> methods for Raisin.
+Provides C<content_type>, C<deserialize> and C<serialize> methods for Raisin.
 
 =cut
